@@ -6,7 +6,7 @@ from pydantic import BaseModel
 from telescope_sdk.common import UserFacingDataType
 
 
-class SequenceStepType(Enum):
+class SequenceStepType(str, Enum):
     EMAIL = 'EMAIL'
 
 
